NativeClassOptions class

Unified management of native resources

Constructors

NativeClassOptions(List? constructorArgs, {Map<String, dynamic>? members, String className = '', InstanceType instanceType = InstanceType.manual, String? instanceId, Map<String, String>? methodMap, bool disableInit = false, String? bridgeKey})
const
NativeClassOptions.fromMap(Map<String, dynamic> map)
@description 从 Map 反序列化,创建一个 NativeClassOptions 实例。 @param {Map<String, dynamic>} map - 包含对象数据的 Map。 @return {NativeClassOptions} 一个新的 NativeClassOptions 实例。
factory

Properties

bridgeKey String?
final
className String
final
constructorArgs List?
final
disableInit bool
final
hashCode int
The hash code for this object.
no setterinherited
instanceId String?
final
instanceType InstanceType
final
members Map<String, dynamic>?
final
methodMap Map<String, String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
@description 将 NativeClassOptions 实例序列化为 Map。 @return {Map<String, dynamic>} 包含对象数据的 Map。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited