NativeResource class

Unified management of native resources

Constructors

NativeResource({String instanceId = '', String className = '', MessageClient? client})

Properties

className String
getter/setter pair
client MessageClient
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instanceId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update({String? instanceId, String? className, MessageClient? client}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited